var searchData=
[
  ['resolution_0',['Resource Resolution',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md9',1,'']]],
  ['resource_20resolution_1',['Resource Resolution',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md9',1,'']]],
  ['rules_2',['Design Rules',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md7',1,'']]]
];
