var searchData=
[
  ['a_20new_20plugin_0',['Adding A New Plugin',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md13',1,'']]],
  ['abi_1',['Segmentation ABI',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md10',1,'']]],
  ['adding_20a_20new_20plugin_2',['Adding A New Plugin',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md13',1,'']]],
  ['and_20flow_3',['Code Modules and Flow',['../dir_68267d1309a1af8e8297ef4c3efbcdba.html#autotoc_md1',1,'']]],
  ['and_20inspection_20modes_4',['Segmentation and Inspection Modes',['../index.html#autotoc_md30',1,'']]],
  ['and_20install_20core_20opencc_5',['1. Build And Install Core OpenCC',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md15',1,'']]],
  ['and_20installation_6',['Naming And Installation',['../dir_38c8d24aef3972a7f87b834274e76e31.html#autotoc_md8',1,'']]],
  ['api_7',['API',['../group__opencc__c__api.html',1,'OpenCC C API'],['../group__opencc__cpp__api.html',1,'OpenCC C++ Comprehensive API'],['../group__opencc__simple__api.html',1,'OpenCC C++ Simple API']]]
];
